/*
** Copyright (©) 2003-2009 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**  
*/


#ifndef INCLUDED_COLOR_H
#define INCLUDED_COLOR_H


#include "libraries.h"
#include <gdk/gdk.h>
#include <gtk/gtk.h>


void color_decimal_to_gdk (unsigned int colour, GdkColor * color);
unsigned int color_gdk_to_decimal (GdkColor * color);
ustring color_decimal_to_hex (unsigned int colour);
void color_widget_default (GtkWidget * widget);
void color_widget_set (GtkWidget * widget, 
                       unsigned int normal_text, unsigned int background, 
                       unsigned int selected_text, unsigned int selection);


#endif
